@@ -149,11 +149,11 @@ class GXDLMSIECLocalPortSetup(GXDLMSObject, IGXDLMSBase):
         if e.index == 1:
             ret = _GXCommon.logicalNameToBytes(self.logicalName)
         elif e.index == 2:
-            ret = self.defaultMode.value
+            ret = self.defaultMode
         elif e.index == 3:
-            ret = self.defaultBaudrate.value
+            ret = self.defaultBaudrate
         elif e.index == 4:
-            ret = self.proposedBaudrate.value
+            ret = self.proposedBaudrate
         elif e.index == 5:
             ret = self.responseTime
         elif e.index == 6:
@@ -180,13 +180,13 @@ class GXDLMSIECLocalPortSetup(GXDLMSObject, IGXDLMSBase):
         elif e.index == 5:
             self.responseTime = e.value
         elif e.index == 6:
-            self.deviceAddress = _GXCommon.changeType(e.value, DataType.STRING)
+            self.deviceAddress = _GXCommon.changeType(settings, e.value, DataType.STRING)
         elif e.index == 7:
-            self.password1 = _GXCommon.changeType(e.value, DataType.STRING)
+            self.password1 = _GXCommon.changeType(settings, e.value, DataType.STRING)
         elif e.index == 8:
-            self.password2 = _GXCommon.changeType(e.value, DataType.STRING)
+            self.password2 = _GXCommon.changeType(settings, e.value, DataType.STRING)
         elif e.index == 9:
-            self.password5 = _GXCommon.changeType(e.value, DataType.STRING)
+            self.password5 = _GXCommon.changeType(settings, e.value, DataType.STRING)
         else:
             e.error = ErrorCode.READ_WRITE_DENIED
 
